@@ -10,6 +10,10 @@ COMMANDS = [
     "list",
     "devices",
     "device_create",
+    "devices_clear",
+    "groups",
+    "group_create",
+    "groups_clear",
     "livelog",
     "signal",
     "reset",
