@@ -1,10 +1,9 @@
 import requests.exceptions
 
 import bond.proto
+from bond.commands.base_command import BaseCommand
 from bond.database import BondDatabase
 
-from .base_command import BaseCommand
-
 
 class RebootCommand(BaseCommand):
     subcmd = "reboot"
